@@ -146,6 +146,7 @@ class Column:
     description: Optional[str] = None
     col_type: str
     sort_order: int
+    archived: bool = False
     stats: List[Stat] = []
     badges: Optional[List[Badge]] = []
     tags: Optional[List[Tag]] = []
@@ -228,6 +229,7 @@ class Table:
     schema: str
     name: str
     key: Optional[str] = None
+    archived: bool = False
     tags: List[Tag] = []
     badges: List[Badge] = []
     table_readers: List[Reader] = []
@@ -248,6 +250,7 @@ class Table:
     total_usage: Optional[int] = None
     unique_usage: Optional[int] = None
     quality: Optional[str] = None
+    row_order: Optional[str] = None # Predefine the order of the rows with a JSON value.
     queries: Optional[List[Query]] = []
     creation_query: Optional[Query] = None
 
